/*
This sketch illustrates ideas from the course "2D Animation and Interaction"
available at www.imaginary-institute.com, and my book "Processing for
Artists and Designers," published by AK Peters. For more of my Processing
programs, visit www.glassner.com or www.imaginary-institute.com
---
Create an animated Moire pattern by drawing two identical images of radiating
spokes. The first image is centered in the window, while the other is centered
on the mouse. To add more visual interest to the effect, the second image rotates 
a little bit more with each frame.
---
Andrew Glassner, version 2, April 2014
*/
float Speed = .0004;      // how many radians we spin each frame
float MouseYOffset = 30;  // vertical correction for web-based sketches
void setup() {
  size(600, 400);
  smooth();
}
void draw() {
  background(255);
  noStroke();
  fill(0, 0, 0);          // we'll draw with black
  pushMatrix();
    translate(width/2, height/2);  // move to the canvas center
    drawStar();
  popMatrix();
  pushMatrix();
    translate(mouseX, mouseY-MouseYOffset);  // center the pattern at the mouse
    rotate(Speed * millis());        // rotate a little more with every frame
    drawStar();
  popMatrix();
}
void drawStar() {
  int numSpokes = 100;  // the number of black spokes radiating from the center
  float radius = sqrt(2.) * ((width > height) ? width : height);  // cover the canvas
  for (int i=0; i<numSpokes; i++) {
      float t0 = map(i, 0, numSpokes-1, 0, TWO_PI);  // starting angle for the stroke
      float t1 = t0 + (TWO_PI/(2*numSpokes));        // ending angle for the stroke
      arc(0, 0, 2*radius, 2*radius, t0, t1);         // draw this stroke
   }
}
void keyPressed() {
  if (key == 's') Speed = max(.00001, Speed*0.8);  // go slower, but never stop
  if (key == 'S') Speed *= 1.2;      // go faster
  if (key == 'y') MouseYOffset++;
  if (key == 'Y') MouseYOffset--;
}
